@@ -20,6 +20,8 @@ FEATURES = [ 'exp_unique_id', 'timesteps', 'sensor_1', 'sensor_2',
        'sensor_19', 'sensor_20', 'sensor_21', 'sensor_22', 'sensor_23',
        'sensor_24', 'result']
 
+TARGET_COL = 'result'
+
 extraction_settings = ComprehensiveFCParameters()
 
 
@@ -71,13 +73,7 @@ def get_relevant_features(X, y, tree_model=xgb):
     return df
 
 
-def get_prediction_features(df, relevant_features, id='exp_unique_id', timesteps='timesteps'):
 
-    fc_parameters = settings.from_columns(df.drop(relevant_features))
-
-    prediction_data = extract_features(df, kind_to_fc_parameters =fc_parameters, column_id=id, column_sort=timesteps)
-
-    return prediction_data
 
 
 
