@@ -17,6 +17,7 @@ from sklearn.metrics import recall_score
 from mlflow.models.signature import infer_signature
 
 from tsfresh.feature_extraction import settings
+import copy
 
 
 
@@ -99,28 +100,22 @@ def objective(trial, df, study_name, model_mode):
         mlflow.set_tracking_uri(
             REMOTE_TRACKING_URI
             )
-        
+
+        df_copy = df.copy(deep=True)
+
+        relevant_features = list(df_copy.drop(TARGET_COL, axis=1).columns)
 
         mlflow.start_run()
 
         
-        # try:
-        #      #construct the corresponding settings object
-        #     fc_parameters = settings.from_columns(df.drop(TARGET_COL, axis=1))
-        # except:
-        #     pass
-
-        relevant_features = df.drop(TARGET_COL, axis=1).columns
 
         # remove unwanted characters from the column names
-        df.columns = df.columns.str.replace('["]', '')
+        df_copy.columns = df_copy.columns.str.replace('["]', '')
 
-        features = df.drop(TARGET_COL, axis=1).columns
+        features = df_copy.drop(TARGET_COL, axis=1)
+        df_copy['result'] = df_copy['result'].replace({'Control': 0, 'Covid': 1})
 
-        # print(features)
-
-
-        clf = setup(df, target=TARGET_COL, silent=True, log_plots=True, experiment_name=study_name, preprocess=False)
+        clf = setup(df_copy, target=TARGET_COL, silent=True, log_plots=True, experiment_name=study_name, preprocess=False)
 
         add_metric('specificity', 'Specificity', specificity)
         remove_metric('MCC')
